# -*- coding: utf-8 -*-
# -----------------------------------
# @CreateTime   : 2020/3/10 3:59
# @Author       : Mark Shawn
# @Email        : shawninjuly@gmai.com
# ------------------------------------

# 若从文件加载，七牛云的设置如下
# 详情可以参见官网：https://developer.qiniu.com/kodo/sdk/1242/python
QINIU_DOMAIN = ''
QINIU_BUCKET = ''
QINIU_AK     = ''
QINIU_SK     = ''