# -*- coding: utf-8 -*-
# -----------------------------------
# @CreateTime   : 2020/3/10 3:59
# @Author       : Mark Shawn
# @Email        : shawninjuly@gmai.com
# ------------------------------------

QINIU_DOMAIN = 'img.nanchuan.site'
QINIU_BUCKET = "pfa"
QINIU_AK     = 'Li-8HoZaqUHFzZ8l87WL-JzBRpjK7c1HTFgSoWso'
QINIU_SK     = '_Y_ywcqqrmpDskjCrpH2A35iOQMjMHdIsdTsTbz0'
